==> gradle-6.1-all.zip: gradle-6.1/src/internal-performance-testing/org/gradle/performance/results/GradleProfilerReporter.java <==
/*
 * Copyright 2019 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.performance.results;

import com.google.common.base.Strings;
import org.gradle.profiler.BenchmarkResultCollector;
import org.gradle.profiler.report.CsvGenerator;
import org.gradle.profiler.report.HtmlGenerator;

import java.io.File;
import java.io.IOException;
import java.io.UncheckedIOException;

public class GradleProfilerReporter implements DataReporter<PerformanceTestResult> {
    private static final String DEBUG_ARTIFACTS_DIRECTORY_PROPERTY_NAME = "org.gradle.performance.debugArtifactsDirectory";
    private final BenchmarkResultCollector resultCollector;

    public GradleProfilerReporter(File fallbackDirectory) {
        String debugArtifactsDirectoryPath = System.getProperty(DEBUG_ARTIFACTS_DIRECTORY_PROPERTY_NAME);
        File debugArtifactsDirectory = Strings.isNullOrEmpty(debugArtifactsDirectoryPath)
            ? fallbackDirectory
            : new File(debugArtifactsDirectoryPath);
        this.resultCollector = new BenchmarkResultCollector(
            new CsvGenerator(new File(debugArtifactsDirectory, "benchmark.csv")),
            new HtmlGenerator(new File(debugArtifactsDirectory, "benchmark.html"))
        );

    }

    @Override
    public void report(PerformanceTestResult results) {
        resultCollector.summarizeResults(line ->
            System.out.println("  " + line)
        );
        try {
            resultCollector.write();
        } catch (IOException e) {
            throw new UncheckedIOException(e);
        }
    }

    public BenchmarkResultCollector getResultCollector() {
        return resultCollector;
    }

    @Override
    public void close() {
    }
}

==> gradle-6.5-all.zip: gradle-6.5/src/internal-performance-testing/org/gradle/performance/results/GradleProfilerReporter.java <==
/*
 * Copyright 2019 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.performance.results;

import com.google.common.base.Strings;
import org.gradle.profiler.BenchmarkResultCollector;
import org.gradle.profiler.report.CsvGenerator;
import org.gradle.profiler.report.HtmlGenerator;

import java.io.File;
import java.io.IOException;
import java.io.UncheckedIOException;

public class GradleProfilerReporter implements DataReporter<PerformanceTestResult> {
    private static final String DEBUG_ARTIFACTS_DIRECTORY_PROPERTY_NAME = "org.gradle.performance.debugArtifactsDirectory";
    private final BenchmarkResultCollector resultCollector;

    public GradleProfilerReporter(File fallbackDirectory) {
        String debugArtifactsDirectoryPath = System.getProperty(DEBUG_ARTIFACTS_DIRECTORY_PROPERTY_NAME);
        File debugArtifactsDirectory = Strings.isNullOrEmpty(debugArtifactsDirectoryPath)
            ? fallbackDirectory
            : new File(debugArtifactsDirectoryPath);
        this.resultCollector = new BenchmarkResultCollector(
            new CsvGenerator(new File(debugArtifactsDirectory, "benchmark.csv"), CsvGenerator.Format.LONG),
            new HtmlGenerator(new File(debugArtifactsDirectory, "benchmark.html"))
        );

    }

    @Override
    public void report(PerformanceTestResult results) {
        resultCollector.summarizeResults(line ->
            System.out.println("  " + line)
        );
        try {
            resultCollector.write();
        } catch (IOException e) {
            throw new UncheckedIOException(e);
        }
    }

    public BenchmarkResultCollector getResultCollector() {
        return resultCollector;
    }

    @Override
    public void close() {
    }
}
